Enum LyricsError
pub enum LyricsError {
TimestampOffsetOverflow,
UnknownKey {
key: String,
},
Timestamp(TimestampError),
Nom {
input: String,
error: ErrorKind,
},
}Expand description
Error indicating why lyrics couldn’t be parsed as LRC.
Variants
TimestampOffsetOverflow
An overflow occurred while offsetting timestamps with the value of the LRC offset tag
(eg. [offset: -100]).
Try adjusting the offset value or removing the offset tag entirely.
UnknownKey
Encountered an ID tag with an unknown key.
Remove the broken tag.
Timestamp(TimestampError)
Tag timestamps were not ordered correctly.
Nom
Parsing failed due to a syntax error.