LineTag

Struct LineTag 

pub struct LineTag {
    pub timestamp: Duration,
    pub segments: Vec<SegmentTag>,
}
A single line in the synced lyrics.

Fields

timestamp: Duration

The timestamp at which the line starts.

Can be the same as or earlier than the timestamp of first segment (if the A2 extension is used).

segments: Vec<SegmentTag>

Timestamped segments of the line.

With regular LRC files, this will contain at most one element. If the enhanced LRC format is used, it may contain more elements.

Implementations



impl LineTag

pub fn new(timestamp: Duration, content: String) -> LineTag

Create a new line tag with a single segment with the same timestamp.

Examples
assert_eq!(
    LineTag::new(Duration::from_secs(1), "La la la".to_string()),
    // You can save a lot of boilerplate code
    LineTag {
        timestamp: Duration::from_secs(1),
        segments: vec![SegmentTag {
            timestamp: Duration::from_secs(1),
            content: "La la la".to_string()
        }]
    }
);

pub fn timestamp(&mut self, timestamp: Duration) -> Option<&mut LineTag>

Sets the timestamp of the line.

Returns None if the timestamp is later than the first segment of the line.

pub fn segment( &mut self, segment: SegmentTag, ) -> Result<&mut LineTag, TimestampError>

Adds a segment to the line.

Prefer using this method over manually adding segments to lines as it ensures that the timestamp order stays correct. If you need to add segments manually, use the check_timestamp_order method to verify the timestamp order.

pub fn segments( &mut self, segments: &[SegmentTag], ) -> Result<&mut LineTag, TimestampError>

Adds multiple segments to the line.

Prefer using this method over manually adding segments to lines as it ensures that the timestamp order stays correct. If you need to add segments manually, use the check_timestamp_order method to verify the timestamp order.