pub struct MusicLibrary {
pub playlists: Vec<Arc<Playlist>>,
pub tracks: Vec<Arc<Track>>,
pub albums: Vec<Arc<Album>>,
pub artists: Vec<Arc<Artist>>,
pub genres: Vec<Arc<Genre>>,
/* private fields */
}Fields
playlists: Vec<Arc<Playlist>>tracks: Vec<Arc<Track>>albums: Vec<Arc<Album>>artists: Vec<Arc<Artist>>genres: Vec<Arc<Genre>>Implementations
Sourceimpl MusicLibrary
impl MusicLibrary
pub fn find_track_by_path(&self, path: &Path) -> Option<Arc<Track>>
pub fn find_artist(&self, name: &str) -> Option<&Arc<Artist>>
pub fn find_playlist_by_name(&self, name: &str) -> Option<&Arc<Playlist>>
pub fn find_playlist_by_id(&self, id: u64) -> Option<&Arc<Playlist>>
pub fn find_album(&self, title: &str) -> Option<&Arc<Album>>
pub fn find_genre(&self, name: &str) -> Option<&Arc<Genre>>
Sourcepub fn get_default_playlist_name(&self) -> String
pub fn get_default_playlist_name(&self) -> String
Returns the default playlist name (“New Playlist”).
If a playlist with the default name exists, then a number will be added to the end of the playlist name so it’s unique, eg. “New Playlist 1”, “New Playlist 2”, etc.
Sourcepub fn tracks_from_hashes(&self, hashes: Vec<u64>) -> HashMatchingResult
pub fn tracks_from_hashes(&self, hashes: Vec<u64>) -> HashMatchingResult
Retrieves tracks corresponding to a list of provided hashes.
pub fn remove_playlists(&mut self, playlists: Vec<String>) -> Result<(), Error>
pub fn create_playlist( &mut self, name: String, track_paths: &Option<Vec<PathBuf>>, ) -> Result<(), Error>
pub fn rename_playlist( &mut self, source: &str, target: &str, ) -> Result<(), Error>
pub fn add_tracks( &mut self, name: &str, tracks: Vec<PathBuf>, ) -> Result<(), Error>
pub fn remove_tracks( &mut self, name: &str, tracks: Vec<usize>, ) -> Result<(), Error>
pub fn import_m3u8_playlist( &mut self, path: &PathBuf, name: Option<String>, ) -> Result<(), Error>