pub struct Playlist {
pub name: String,
pub tracks: Vec<Arc<Track>>,
pub duration: Duration,
pub cover: Cover,
pub id: u64,
/* private fields */
}Fields
name: Stringtracks: Vec<Arc<Track>>duration: Durationcover: Coverid: u64Unique ID for identifying the playlist in the library.
This ID is not dependent on the contents of the playlist or it’s name, and once a playlist with a specific ID has been created, no new playlist can reclaim it.