SyncedLyrics

Struct SyncedLyrics 

pub struct SyncedLyrics {
    pub title: Option<String>,
    pub artist: Option<String>,
    pub album: Option<String>,
    pub author: Option<String>,
    pub lyricist: Option<String>,
    pub length: Option<Duration>,
    pub file_author: Option<String>,
    pub tool: Option<LRCTool>,
    pub comments: Vec<String>,
    pub lines: Vec<LineTag>,
}
Lyrics grouped into timestamped segments with additional metadata.

Fields

title: Option<String>

Title of the song.

artist: Option<String>

Artist performing the song.

album: Option<String>

Album the song is from.

author: Option<String>

Author of the song.

lyricist: Option<String>

Lyricist of the song.

length: Option<Duration>

Length of the song.

file_author: Option<String>

Author of the LRC file (not the song).

tool: Option<LRCTool>

Info on the player or editor that created the LRC file.

comments: Vec<String>

Comments found in the lyrics.

lines: Vec<LineTag>

LRC segments grouped by lines.

Implementations



impl SyncedLyrics

pub fn line( &mut self, line: LineTag, ) -> Result<&mut SyncedLyrics, TimestampError>

Adds a line to the lyrics.

Prefer using this method over manually adding lines to lyrics as it ensures that the timestamp order stays correct. If you need to add lines manually, use the check_timestamp_order method to verify the timestamp order.

pub fn lines( &mut self, lines: &[LineTag], ) -> Result<&mut SyncedLyrics, TimestampError>

Adds multiple lines to the lyrics.

Prefer using this method over manually adding lines to lyrics as it ensures that the timestamp order stays correct. If you need to add lines manually, use the check_timestamp_order method to verify the timestamp order.

pub fn try_new(tags: Vec<LineTag>) -> Result<SyncedLyrics, TimestampError>

Creates an empty synced lyrics struct with some timed tags.

Returns an error if the timestamp order is not correct.

pub fn serialize(self) -> String

Serialize the struct to LRC format.

NOTE: This method may not always produce the same output as the input parsed to create the data structure. For instance, the original placement of ID tags and comments is not preserved, and the offset tag is omitted as it is applied by the parser.

It should, however, always produce the same result for input serialized from its output.

For instance:

let input = include_str!("../assets/example.lrc");
let parsed = SyncedLyrics::parse(&input).unwrap();
let parsed_twice = SyncedLyrics::parse(&parsed.clone().serialize())
    .unwrap()
    .serialize();
assert_eq!(parsed.serialize(), parsed_twice);

pub fn parse(input: &str) -> Result<SyncedLyrics, Error>

Parses LRC lyrics data.

Examples

Parse some lyrics

let content = "[ti:My awesome song]
[00:02.50] La la la
[00:05.10] <00:05.10> La la la <00:06.30> la la la";
let lyrics = SyncedLyrics::parse(content).unwrap();

Parser fails to parse content with invalid ID tags

let content = "[fun:I am an invalid ID tag]";
assert_eq!(
    SyncedLyrics::parse(content),
    Err(Error::UnknownKey { key: "fun".to_string() })
);

Parser fails to parse content with invalid timestamp order

let content = "[00:02.10] First line
[00:01.90] My timestamp is wrong!";
assert_eq!(
    SyncedLyrics::parse(content),
    Err(Error::Timestamp(lrc_rs::TimestampError {
        line: Some(1),
        segment: None,
        expected: lrc_rs::TimestampConstraint::GreaterThan(Duration::from_secs_f32(2.10)),
        actual: Duration::from_secs_f32(1.9),
    }))
);