pub enum Progress {
FindingTracks,
Indexing {
progress: f32,
},
RebuildingLibrary,
RestoringState,
Done,
Failed(Error),
}Variants
FindingTracks
First step of the loading process.
The indexer finds files in the music library to index.
This step usually takes under 100ms.
Indexing
Second step of the loading process.
The indexer goes through all of the found files and attempts to gather audio metadata from them. During this process track covers are also cached.
This is the longest step of the loading process. The time it takes to complete this step heavily depends on on whether track covers are already cached (warm start) or not (cold start), and how many tracks are in the library.
Eg. for my 908-track music library, cold start takes about 4.24s, and warm start just 0.26s.
RebuildingLibrary
Third step of the loading process.
After all the tracks have been gathered, the backend rebuilds the virtual library from the track tags. It rebuilds artists, albums and genres, as well as hash maps used to quickly find items in the music library.
Usually takes under a 100ms, depending on library size.
RestoringState
Fourth step of the loading process.
The playlists are restored from disk.
NOTE: This step is skipped if the playlists file is not present.
Done
The loading process has finished.
Failed(Error)
The loading process has failed irrecoverably and will not restart.